@@ -332,9 +332,8 @@ def radcal(ras, save=False, quiet=True, debug=False):
         hdrdict={}
 
         for key in indices: 
-            dat[key]=dc(rasfits[indices[key]].data[...,lamwin[key][0]:lamwin[key][1]])
-
             if key!='NUV' and key!='FUV': #Not full disc
+                dat[key]=dc(rasfits[indices[key]].data[...,lamwin[key][0]:lamwin[key][1]])
                 for ind, _ in np.ndenumerate(dat[key][...,0]):
                     dat[key][ind]=np.multiply(dat[key][ind], rcfs[key])
                 hdrdict[key]=dc(rasfits[indices[key]].header)
@@ -362,12 +361,14 @@ def radcal(ras, save=False, quiet=True, debug=False):
                 hdr0['TDP99_'+str(indices[key])]=flatdat[int(np.round(len(flatdat)*0.99))]
                 del flatdat
             else:
+                dat[key]=dc(rasfits[indices[key]].data[lamwin[key][0]:lamwin[key][1]])
                 for ind, _ in np.ndenumerate(dat[key][0]):
-                    dat[key][ind]=np.multiply(dat[key][ind], rcfs[key])
+                    dat[key][ind]=np.multiply(dat[key][:,ind[0], ind[1]], rcfs[key])
                 hdrdict[key]=dc(rasfits[indices[key]].header)
                 hdrdict[key]['CRVAL3']=wvlns[key][lamwin[key][0]]
                 hdrdict[key]['NAXIS3']=lamwin[key][1]-lamwin[key][0]+1 #Counting "0", of course
 
+
         if key!='NUV' and key!='FUV': #Full disc
             for ind, key in enumerate(dat):
                 if ind==0:
@@ -399,7 +400,7 @@ def radcal(ras, save=False, quiet=True, debug=False):
         
         else:
             phdu=fits.PrimaryHDU(dat[list(indices.keys())[0]], header=hdrdict[list(indices.keys())[0]])
-            hduls[phdu]
+            hduls=[phdu]
             for hds in range(1, len(rasfits)):
                 hduls.append(dc(asfits[hds]))
 
